require File.expand_path('../../../../spec_helper', __FILE__)
require File.expand_path('../spec_helper', __FILE__)

describe "Net::FTP#set_socket" do
  # TODO: I won't spec this method, as it is not used
  #       anywhere and it should be private anyway.
  #it "needs to be reviewed for spec completeness"
end
